@@ -5,13 +5,15 @@ try:
     import sys
 
     import oracledb
-    from oracledb.exceptions import DatabaseError
 
     oracledb.version = "8.3.0"
     sys.modules["cx_Oracle"] = oracledb
     try:
         oracledb.init_oracle_client()
-    except DatabaseError:
+    # Here we're ignoring the DatabaseError from oracledb.
+    # Because there may be side effects of re-importing in some cases,
+    # we must mute all exceptions.
+    except:  # noqa
         pass
 except ImportError:
     pass
